@@ -38,4 +38,11 @@ test_that("HydePlotOptions - restoreDefaults",
     HydePlotOptions(restorePackageDefaults = TRUE)
     plot(BlackJack)},
     not(throws_error()))
+})
+
+test_that("Remove Deterministic Nodes",
+{
+  expect_that({
+    plot(BlackJack, removeDeterm = TRUE)},
+    not(throws_error()))
 })
\ No newline at end of file
